@@ -1,4 +1,4 @@
-def leer_pdf(path):
+def leer_pdf():
     try:
         text = 'Hola'
         print(text)
